pilas.sonidos

Package pilas :: Module sonidos |
[hide private]
[frames] | no frames]

# Module sonidos

source code

Functions | [hide private]
cargar(ruta) Carga un sonido para reproducir, donde el argumento ``ruta`` indica cual es el archivo. | source code

Variables | [hide private]
| __package__ = ``'``pilas``'``

Function Details | [hide private]

### cargar(ruta) | source code
    Carga un sonido para reproducir, donde el argumento ``ruta`` indica cual es el archivo.

    Por ejemplo::

        import pilas

        risa = pilas.sonidos.cargar("risa.ogg")

    En caso de éxito retorna el objeto Sound, que se puede
    reproducir usando el método ``reproducir()``, por ejemplo::

        risa.reproducir()

    El directorio de búsqueda del sonido sigue el siguiente orden:

        * primero busca en el directorio actual.
        * luego en 'data'.
        * por último en el directorio estándar de la biblioteca.

    En caso de error genera una excepción de tipo IOError.